# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v2/market.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"injective/exchange/v2/market.proto\x12\x15injective.exchange.v2\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x84\x01\n\x13MarketFeeMultiplier\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12J\n\x0e\x66\x65\x65_multiplier\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\rfeeMultiplier:\x04\x88\xa0\x1f\x00\"\xb3\x06\n\nSpotMarket\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12\x1d\n\nbase_denom\x18\x02 \x01(\tR\tbaseDenom\x12\x1f\n\x0bquote_denom\x18\x03 \x01(\tR\nquoteDenom\x12I\n\x0emaker_fee_rate\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0cmakerFeeRate\x12I\n\x0etaker_fee_rate\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ctakerFeeRate\x12X\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13relayerFeeShareRate\x12\x1b\n\tmarket_id\x18\x07 \x01(\tR\x08marketId\x12;\n\x06status\x18\x08 \x01(\x0e\x32#.injective.exchange.v2.MarketStatusR\x06status\x12R\n\x13min_price_tick_size\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x10minPriceTickSize\x12X\n\x16min_quantity_tick_size\x18\n \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13minQuantityTickSize\x12\x46\n\x0cmin_notional\x18\x0b \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bminNotional\x12\x14\n\x05\x61\x64min\x18\x0c \x01(\tR\x05\x61\x64min\x12+\n\x11\x61\x64min_permissions\x18\r \x01(\rR\x10\x61\x64minPermissions\x12#\n\rbase_decimals\x18\x0e \x01(\rR\x0c\x62\x61seDecimals\x12%\n\x0equote_decimals\x18\x0f \x01(\rR\rquoteDecimals\"\xf9\x08\n\x13\x42inaryOptionsMarket\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12#\n\roracle_symbol\x18\x02 \x01(\tR\x0coracleSymbol\x12\'\n\x0foracle_provider\x18\x03 \x01(\tR\x0eoracleProvider\x12\x45\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12.\n\x13oracle_scale_factor\x18\x05 \x01(\rR\x11oracleScaleFactor\x12\x31\n\x14\x65xpiration_timestamp\x18\x06 \x01(\x03R\x13\x65xpirationTimestamp\x12\x31\n\x14settlement_timestamp\x18\x07 \x01(\x03R\x13settlementTimestamp\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\tR\x05\x61\x64min\x12\x1f\n\x0bquote_denom\x18\t \x01(\tR\nquoteDenom\x12\x1b\n\tmarket_id\x18\n \x01(\tR\x08marketId\x12I\n\x0emaker_fee_rate\x18\x0b \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0cmakerFeeRate\x12I\n\x0etaker_fee_rate\x18\x0c \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ctakerFeeRate\x12X\n\x16relayer_fee_share_rate\x18\r \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13relayerFeeShareRate\x12;\n\x06status\x18\x0e \x01(\x0e\x32#.injective.exchange.v2.MarketStatusR\x06status\x12R\n\x13min_price_tick_size\x18\x0f \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x10minPriceTickSize\x12X\n\x16min_quantity_tick_size\x18\x10 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13minQuantityTickSize\x12N\n\x10settlement_price\x18\x11 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0fsettlementPrice\x12\x46\n\x0cmin_notional\x18\x12 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bminNotional\x12+\n\x11\x61\x64min_permissions\x18\x13 \x01(\rR\x10\x61\x64minPermissions\x12%\n\x0equote_decimals\x18\x14 \x01(\rR\rquoteDecimals:\x04\x88\xa0\x1f\x00\"\xe3\t\n\x10\x44\x65rivativeMarket\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12\x1f\n\x0boracle_base\x18\x02 \x01(\tR\noracleBase\x12!\n\x0coracle_quote\x18\x03 \x01(\tR\x0boracleQuote\x12\x45\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12.\n\x13oracle_scale_factor\x18\x05 \x01(\rR\x11oracleScaleFactor\x12\x1f\n\x0bquote_denom\x18\x06 \x01(\tR\nquoteDenom\x12\x1b\n\tmarket_id\x18\x07 \x01(\tR\x08marketId\x12U\n\x14initial_margin_ratio\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x12initialMarginRatio\x12]\n\x18maintenance_margin_ratio\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x16maintenanceMarginRatio\x12I\n\x0emaker_fee_rate\x18\n \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0cmakerFeeRate\x12I\n\x0etaker_fee_rate\x18\x0b \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ctakerFeeRate\x12X\n\x16relayer_fee_share_rate\x18\x0c \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13relayerFeeShareRate\x12 \n\x0bisPerpetual\x18\r \x01(\x08R\x0bisPerpetual\x12;\n\x06status\x18\x0e \x01(\x0e\x32#.injective.exchange.v2.MarketStatusR\x06status\x12R\n\x13min_price_tick_size\x18\x0f \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x10minPriceTickSize\x12X\n\x16min_quantity_tick_size\x18\x10 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13minQuantityTickSize\x12\x46\n\x0cmin_notional\x18\x11 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bminNotional\x12\x14\n\x05\x61\x64min\x18\x12 \x01(\tR\x05\x61\x64min\x12+\n\x11\x61\x64min_permissions\x18\x13 \x01(\rR\x10\x61\x64minPermissions\x12%\n\x0equote_decimals\x18\x14 \x01(\rR\rquoteDecimals\x12S\n\x13reduce_margin_ratio\x18\x15 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x11reduceMarginRatio:\x04\x88\xa0\x1f\x00\"\x8d\x01\n\x1e\x44\x65rivativeMarketSettlementInfo\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12N\n\x10settlement_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0fsettlementPrice\"n\n\x0cMarketVolume\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x41\n\x06volume\x18\x02 \x01(\x0b\x32#.injective.exchange.v2.VolumeRecordB\x04\xc8\xde\x1f\x00R\x06volume\"\x9e\x01\n\x0cVolumeRecord\x12\x46\n\x0cmaker_volume\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bmakerVolume\x12\x46\n\x0ctaker_volume\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0btakerVolume\"\x8c\x01\n\x1c\x45xpiryFuturesMarketInfoState\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12O\n\x0bmarket_info\x18\x02 \x01(\x0b\x32..injective.exchange.v2.ExpiryFuturesMarketInfoR\nmarketInfo\"\x83\x01\n\x1bPerpetualMarketFundingState\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12G\n\x07\x66unding\x18\x02 \x01(\x0b\x32-.injective.exchange.v2.PerpetualMarketFundingR\x07\x66unding\"\xe4\x02\n\x17\x45xpiryFuturesMarketInfo\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x31\n\x14\x65xpiration_timestamp\x18\x02 \x01(\x03R\x13\x65xpirationTimestamp\x12\x30\n\x14twap_start_timestamp\x18\x03 \x01(\x03R\x12twapStartTimestamp\x12w\n&expiration_twap_start_price_cumulative\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\"expirationTwapStartPriceCumulative\x12N\n\x10settlement_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0fsettlementPrice\"\xc6\x02\n\x13PerpetualMarketInfo\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12Z\n\x17hourly_funding_rate_cap\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x14hourlyFundingRateCap\x12U\n\x14hourly_interest_rate\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x12hourlyInterestRate\x12\x34\n\x16next_funding_timestamp\x18\x04 \x01(\x03R\x14nextFundingTimestamp\x12)\n\x10\x66unding_interval\x18\x05 \x01(\x03R\x0f\x66undingInterval\"\xe3\x01\n\x16PerpetualMarketFunding\x12R\n\x12\x63umulative_funding\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x11\x63umulativeFunding\x12N\n\x10\x63umulative_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0f\x63umulativePrice\x12%\n\x0elast_timestamp\x18\x03 \x01(\x03R\rlastTimestamp*T\n\x0cMarketStatus\x12\x0f\n\x0bUnspecified\x10\x00\x12\n\n\x06\x41\x63tive\x10\x01\x12\n\n\x06Paused\x10\x02\x12\x0e\n\nDemolished\x10\x03\x12\x0b\n\x07\x45xpired\x10\x04\x42\xf1\x01\n\x19\x63om.injective.exchange.v2B\x0bMarketProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\xa2\x02\x03IEX\xaa\x02\x15Injective.Exchange.V2\xca\x02\x15Injective\\Exchange\\V2\xe2\x02!Injective\\Exchange\\V2\\GPBMetadata\xea\x02\x17Injective::Exchange::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v2.market_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.exchange.v2B\013MarketProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\242\002\003IEX\252\002\025Injective.Exchange.V2\312\002\025Injective\\Exchange\\V2\342\002!Injective\\Exchange\\V2\\GPBMetadata\352\002\027Injective::Exchange::V2'
  _globals['_MARKETFEEMULTIPLIER'].fields_by_name['fee_multiplier']._loaded_options = None
  _globals['_MARKETFEEMULTIPLIER'].fields_by_name['fee_multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MARKETFEEMULTIPLIER']._loaded_options = None
  _globals['_MARKETFEEMULTIPLIER']._serialized_options = b'\210\240\037\000'
  _globals['_SPOTMARKET'].fields_by_name['maker_fee_rate']._loaded_options = None
  _globals['_SPOTMARKET'].fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTMARKET'].fields_by_name['taker_fee_rate']._loaded_options = None
  _globals['_SPOTMARKET'].fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTMARKET'].fields_by_name['relayer_fee_share_rate']._loaded_options = None
  _globals['_SPOTMARKET'].fields_by_name['relayer_fee_share_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTMARKET'].fields_by_name['min_price_tick_size']._loaded_options = None
  _globals['_SPOTMARKET'].fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTMARKET'].fields_by_name['min_quantity_tick_size']._loaded_options = None
  _globals['_SPOTMARKET'].fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTMARKET'].fields_by_name['min_notional']._loaded_options = None
  _globals['_SPOTMARKET'].fields_by_name['min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['maker_fee_rate']._loaded_options = None
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['taker_fee_rate']._loaded_options = None
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['relayer_fee_share_rate']._loaded_options = None
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['relayer_fee_share_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['min_price_tick_size']._loaded_options = None
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['min_quantity_tick_size']._loaded_options = None
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['settlement_price']._loaded_options = None
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['settlement_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['min_notional']._loaded_options = None
  _globals['_BINARYOPTIONSMARKET'].fields_by_name['min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BINARYOPTIONSMARKET']._loaded_options = None
  _globals['_BINARYOPTIONSMARKET']._serialized_options = b'\210\240\037\000'
  _globals['_DERIVATIVEMARKET'].fields_by_name['initial_margin_ratio']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['initial_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET'].fields_by_name['maintenance_margin_ratio']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['maintenance_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET'].fields_by_name['maker_fee_rate']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET'].fields_by_name['taker_fee_rate']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET'].fields_by_name['relayer_fee_share_rate']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['relayer_fee_share_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET'].fields_by_name['min_price_tick_size']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET'].fields_by_name['min_quantity_tick_size']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET'].fields_by_name['min_notional']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET'].fields_by_name['reduce_margin_ratio']._loaded_options = None
  _globals['_DERIVATIVEMARKET'].fields_by_name['reduce_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKET']._loaded_options = None
  _globals['_DERIVATIVEMARKET']._serialized_options = b'\210\240\037\000'
  _globals['_DERIVATIVEMARKETSETTLEMENTINFO'].fields_by_name['settlement_price']._loaded_options = None
  _globals['_DERIVATIVEMARKETSETTLEMENTINFO'].fields_by_name['settlement_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MARKETVOLUME'].fields_by_name['volume']._loaded_options = None
  _globals['_MARKETVOLUME'].fields_by_name['volume']._serialized_options = b'\310\336\037\000'
  _globals['_VOLUMERECORD'].fields_by_name['maker_volume']._loaded_options = None
  _globals['_VOLUMERECORD'].fields_by_name['maker_volume']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_VOLUMERECORD'].fields_by_name['taker_volume']._loaded_options = None
  _globals['_VOLUMERECORD'].fields_by_name['taker_volume']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EXPIRYFUTURESMARKETINFO'].fields_by_name['expiration_twap_start_price_cumulative']._loaded_options = None
  _globals['_EXPIRYFUTURESMARKETINFO'].fields_by_name['expiration_twap_start_price_cumulative']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EXPIRYFUTURESMARKETINFO'].fields_by_name['settlement_price']._loaded_options = None
  _globals['_EXPIRYFUTURESMARKETINFO'].fields_by_name['settlement_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PERPETUALMARKETINFO'].fields_by_name['hourly_funding_rate_cap']._loaded_options = None
  _globals['_PERPETUALMARKETINFO'].fields_by_name['hourly_funding_rate_cap']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PERPETUALMARKETINFO'].fields_by_name['hourly_interest_rate']._loaded_options = None
  _globals['_PERPETUALMARKETINFO'].fields_by_name['hourly_interest_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PERPETUALMARKETFUNDING'].fields_by_name['cumulative_funding']._loaded_options = None
  _globals['_PERPETUALMARKETFUNDING'].fields_by_name['cumulative_funding']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PERPETUALMARKETFUNDING'].fields_by_name['cumulative_price']._loaded_options = None
  _globals['_PERPETUALMARKETFUNDING'].fields_by_name['cumulative_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MARKETSTATUS']._serialized_start=5093
  _globals['_MARKETSTATUS']._serialized_end=5177
  _globals['_MARKETFEEMULTIPLIER']._serialized_start=123
  _globals['_MARKETFEEMULTIPLIER']._serialized_end=255
  _globals['_SPOTMARKET']._serialized_start=258
  _globals['_SPOTMARKET']._serialized_end=1077
  _globals['_BINARYOPTIONSMARKET']._serialized_start=1080
  _globals['_BINARYOPTIONSMARKET']._serialized_end=2225
  _globals['_DERIVATIVEMARKET']._serialized_start=2228
  _globals['_DERIVATIVEMARKET']._serialized_end=3479
  _globals['_DERIVATIVEMARKETSETTLEMENTINFO']._serialized_start=3482
  _globals['_DERIVATIVEMARKETSETTLEMENTINFO']._serialized_end=3623
  _globals['_MARKETVOLUME']._serialized_start=3625
  _globals['_MARKETVOLUME']._serialized_end=3735
  _globals['_VOLUMERECORD']._serialized_start=3738
  _globals['_VOLUMERECORD']._serialized_end=3896
  _globals['_EXPIRYFUTURESMARKETINFOSTATE']._serialized_start=3899
  _globals['_EXPIRYFUTURESMARKETINFOSTATE']._serialized_end=4039
  _globals['_PERPETUALMARKETFUNDINGSTATE']._serialized_start=4042
  _globals['_PERPETUALMARKETFUNDINGSTATE']._serialized_end=4173
  _globals['_EXPIRYFUTURESMARKETINFO']._serialized_start=4176
  _globals['_EXPIRYFUTURESMARKETINFO']._serialized_end=4532
  _globals['_PERPETUALMARKETINFO']._serialized_start=4535
  _globals['_PERPETUALMARKETINFO']._serialized_end=4861
  _globals['_PERPETUALMARKETFUNDING']._serialized_start=4864
  _globals['_PERPETUALMARKETFUNDING']._serialized_end=5091
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, Optional

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.exchange import (
    injective_portfolio_rpc_pb2 as exchange_portfolio_pb,
    injective_portfolio_rpc_pb2_grpc as exchange_portfolio_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IndexerGrpcPortfolioApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = self._stub = exchange_portfolio_grpc.InjectivePortfolioRPCStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_account_portfolio(self, account_address: str) -> Dict[str, Any]:
        request = exchange_portfolio_pb.AccountPortfolioRequest(account_address=account_address)
        response = await self._execute_call(call=self._stub.AccountPortfolio, request=request)

        return response

    async def fetch_account_portfolio_balances(
        self, account_address: str, usd: Optional[bool] = None
    ) -> Dict[str, Any]:
        request = exchange_portfolio_pb.AccountPortfolioBalancesRequest(account_address=account_address, usd=usd)
        response = await self._execute_call(call=self._stub.AccountPortfolioBalances, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/ocr/v1beta1/tx.proto\x12\x15injective.ocr.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x8d\x01\n\rMsgCreateFeed\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x39\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfigR\x06\x63onfig:)\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x11ocr/MsgCreateFeed\"\x17\n\x15MsgCreateFeedResponse\"\xb0\x03\n\rMsgUpdateFeed\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x18\n\x07signers\x18\x03 \x03(\tR\x07signers\x12\"\n\x0ctransmitters\x18\x04 \x03(\tR\x0ctransmitters\x12O\n\x14link_per_observation\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x01\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x12linkPerObservation\x12Q\n\x15link_per_transmission\x18\x06 \x01(\tB\x1d\xc8\xde\x1f\x01\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x13linkPerTransmission\x12\x1d\n\nlink_denom\x18\x07 \x01(\tR\tlinkDenom\x12\x1d\n\nfeed_admin\x18\x08 \x01(\tR\tfeedAdmin\x12#\n\rbilling_admin\x18\t \x01(\tR\x0c\x62illingAdmin:)\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x11ocr/MsgUpdateFeed\"\x17\n\x15MsgUpdateFeedResponse\"\xbd\x02\n\x0bMsgTransmit\x12 \n\x0btransmitter\x18\x01 \x01(\tR\x0btransmitter\x12#\n\rconfig_digest\x18\x02 \x01(\x0cR\x0c\x63onfigDigest\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x14\n\x05\x65poch\x18\x04 \x01(\x04R\x05\x65poch\x12\x14\n\x05round\x18\x05 \x01(\x04R\x05round\x12\x1d\n\nextra_hash\x18\x06 \x01(\x0cR\textraHash\x12\x35\n\x06report\x18\x07 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ReportR\x06report\x12\x1e\n\nsignatures\x18\x08 \x03(\x0cR\nsignatures:,\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x0btransmitter\x8a\xe7\xb0*\x0focr/MsgTransmit\"\x15\n\x13MsgTransmitResponse\"\xb4\x01\n\x15MsgFundFeedRewardPool\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount:1\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19ocr/MsgFundFeedRewardPool\"\x1f\n\x1dMsgFundFeedRewardPoolResponse\"\xbc\x01\n\x19MsgWithdrawFeedRewardPool\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount:5\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1docr/MsgWithdrawFeedRewardPool\"#\n!MsgWithdrawFeedRewardPoolResponse\"\xa5\x01\n\x0cMsgSetPayees\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\tR\x06\x66\x65\x65\x64Id\x12\"\n\x0ctransmitters\x18\x03 \x03(\tR\x0ctransmitters\x12\x16\n\x06payees\x18\x04 \x03(\tR\x06payees:(\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x10ocr/MsgSetPayees\"\x16\n\x14MsgSetPayeesResponse\"\xb7\x01\n\x14MsgTransferPayeeship\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12 \n\x0btransmitter\x18\x02 \x01(\tR\x0btransmitter\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x1a\n\x08proposed\x18\x04 \x01(\tR\x08proposed:0\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x18ocr/MsgTransferPayeeship\"\x1e\n\x1cMsgTransferPayeeshipResponse\"\x9a\x01\n\x12MsgAcceptPayeeship\x12\x14\n\x05payee\x18\x01 \x01(\tR\x05payee\x12 \n\x0btransmitter\x18\x02 \x01(\tR\x0btransmitter\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\tR\x06\x66\x65\x65\x64Id:3\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x0btransmitter\x8a\xe7\xb0*\x16ocr/MsgAcceptPayeeship\"\x1c\n\x1aMsgAcceptPayeeshipResponse\"\xae\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12;\n\x06params\x18\x02 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:&\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x13ocr/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\xdc\x07\n\x03Msg\x12`\n\nCreateFeed\x12$.injective.ocr.v1beta1.MsgCreateFeed\x1a,.injective.ocr.v1beta1.MsgCreateFeedResponse\x12`\n\nUpdateFeed\x12$.injective.ocr.v1beta1.MsgUpdateFeed\x1a,.injective.ocr.v1beta1.MsgUpdateFeedResponse\x12Z\n\x08Transmit\x12\".injective.ocr.v1beta1.MsgTransmit\x1a*.injective.ocr.v1beta1.MsgTransmitResponse\x12x\n\x12\x46undFeedRewardPool\x12,.injective.ocr.v1beta1.MsgFundFeedRewardPool\x1a\x34.injective.ocr.v1beta1.MsgFundFeedRewardPoolResponse\x12\x84\x01\n\x16WithdrawFeedRewardPool\x12\x30.injective.ocr.v1beta1.MsgWithdrawFeedRewardPool\x1a\x38.injective.ocr.v1beta1.MsgWithdrawFeedRewardPoolResponse\x12]\n\tSetPayees\x12#.injective.ocr.v1beta1.MsgSetPayees\x1a+.injective.ocr.v1beta1.MsgSetPayeesResponse\x12u\n\x11TransferPayeeship\x12+.injective.ocr.v1beta1.MsgTransferPayeeship\x1a\x33.injective.ocr.v1beta1.MsgTransferPayeeshipResponse\x12o\n\x0f\x41\x63\x63\x65ptPayeeship\x12).injective.ocr.v1beta1.MsgAcceptPayeeship\x1a\x31.injective.ocr.v1beta1.MsgAcceptPayeeshipResponse\x12\x66\n\x0cUpdateParams\x12&.injective.ocr.v1beta1.MsgUpdateParams\x1a..injective.ocr.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xe5\x01\n\x19\x63om.injective.ocr.v1beta1B\x07TxProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types\xa2\x02\x03IOX\xaa\x02\x15Injective.Ocr.V1beta1\xca\x02\x15Injective\\Ocr\\V1beta1\xe2\x02!Injective\\Ocr\\V1beta1\\GPBMetadata\xea\x02\x17Injective::Ocr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.ocr.v1beta1B\007TxProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types\242\002\003IOX\252\002\025Injective.Ocr.V1beta1\312\002\025Injective\\Ocr\\V1beta1\342\002!Injective\\Ocr\\V1beta1\\GPBMetadata\352\002\027Injective::Ocr::V1beta1'
  _globals['_MSGCREATEFEED']._loaded_options = None
  _globals['_MSGCREATEFEED']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\021ocr/MsgCreateFeed'
  _globals['_MSGUPDATEFEED'].fields_by_name['link_per_observation']._loaded_options = None
  _globals['_MSGUPDATEFEED'].fields_by_name['link_per_observation']._serialized_options = b'\310\336\037\001\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MSGUPDATEFEED'].fields_by_name['link_per_transmission']._loaded_options = None
  _globals['_MSGUPDATEFEED'].fields_by_name['link_per_transmission']._serialized_options = b'\310\336\037\001\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MSGUPDATEFEED']._loaded_options = None
  _globals['_MSGUPDATEFEED']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\021ocr/MsgUpdateFeed'
  _globals['_MSGTRANSMIT']._loaded_options = None
  _globals['_MSGTRANSMIT']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\013transmitter\212\347\260*\017ocr/MsgTransmit'
  _globals['_MSGFUNDFEEDREWARDPOOL'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGFUNDFEEDREWARDPOOL'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGFUNDFEEDREWARDPOOL']._loaded_options = None
  _globals['_MSGFUNDFEEDREWARDPOOL']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\031ocr/MsgFundFeedRewardPool'
  _globals['_MSGWITHDRAWFEEDREWARDPOOL'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGWITHDRAWFEEDREWARDPOOL'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGWITHDRAWFEEDREWARDPOOL']._loaded_options = None
  _globals['_MSGWITHDRAWFEEDREWARDPOOL']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\035ocr/MsgWithdrawFeedRewardPool'
  _globals['_MSGSETPAYEES']._loaded_options = None
  _globals['_MSGSETPAYEES']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\020ocr/MsgSetPayees'
  _globals['_MSGTRANSFERPAYEESHIP']._loaded_options = None
  _globals['_MSGTRANSFERPAYEESHIP']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\030ocr/MsgTransferPayeeship'
  _globals['_MSGACCEPTPAYEESHIP']._loaded_options = None
  _globals['_MSGACCEPTPAYEESHIP']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\013transmitter\212\347\260*\026ocr/MsgAcceptPayeeship'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\023ocr/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEFEED']._serialized_start=216
  _globals['_MSGCREATEFEED']._serialized_end=357
  _globals['_MSGCREATEFEEDRESPONSE']._serialized_start=359
  _globals['_MSGCREATEFEEDRESPONSE']._serialized_end=382
  _globals['_MSGUPDATEFEED']._serialized_start=385
  _globals['_MSGUPDATEFEED']._serialized_end=817
  _globals['_MSGUPDATEFEEDRESPONSE']._serialized_start=819
  _globals['_MSGUPDATEFEEDRESPONSE']._serialized_end=842
  _globals['_MSGTRANSMIT']._serialized_start=845
  _globals['_MSGTRANSMIT']._serialized_end=1162
  _globals['_MSGTRANSMITRESPONSE']._serialized_start=1164
  _globals['_MSGTRANSMITRESPONSE']._serialized_end=1185
  _globals['_MSGFUNDFEEDREWARDPOOL']._serialized_start=1188
  _globals['_MSGFUNDFEEDREWARDPOOL']._serialized_end=1368
  _globals['_MSGFUNDFEEDREWARDPOOLRESPONSE']._serialized_start=1370
  _globals['_MSGFUNDFEEDREWARDPOOLRESPONSE']._serialized_end=1401
  _globals['_MSGWITHDRAWFEEDREWARDPOOL']._serialized_start=1404
  _globals['_MSGWITHDRAWFEEDREWARDPOOL']._serialized_end=1592
  _globals['_MSGWITHDRAWFEEDREWARDPOOLRESPONSE']._serialized_start=1594
  _globals['_MSGWITHDRAWFEEDREWARDPOOLRESPONSE']._serialized_end=1629
  _globals['_MSGSETPAYEES']._serialized_start=1632
  _globals['_MSGSETPAYEES']._serialized_end=1797
  _globals['_MSGSETPAYEESRESPONSE']._serialized_start=1799
  _globals['_MSGSETPAYEESRESPONSE']._serialized_end=1821
  _globals['_MSGTRANSFERPAYEESHIP']._serialized_start=1824
  _globals['_MSGTRANSFERPAYEESHIP']._serialized_end=2007
  _globals['_MSGTRANSFERPAYEESHIPRESPONSE']._serialized_start=2009
  _globals['_MSGTRANSFERPAYEESHIPRESPONSE']._serialized_end=2039
  _globals['_MSGACCEPTPAYEESHIP']._serialized_start=2042
  _globals['_MSGACCEPTPAYEESHIP']._serialized_end=2196
  _globals['_MSGACCEPTPAYEESHIPRESPONSE']._serialized_start=2198
  _globals['_MSGACCEPTPAYEESHIPRESPONSE']._serialized_end=2226
  _globals['_MSGUPDATEPARAMS']._serialized_start=2229
  _globals['_MSGUPDATEPARAMS']._serialized_end=2403
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=2405
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=2430
  _globals['_MSG']._serialized_start=2433
  _globals['_MSG']._serialized_end=3421
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/txfees/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"osmosis/txfees/v1beta1/query.proto\x12\x16osmosis.txfees.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\"\x18\n\x16QueryEipBaseFeeRequest\"l\n\x17QueryEipBaseFeeResponse\x12Q\n\x08\x62\x61se_fee\x18\x01 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x0fyaml:\"base_fee\"R\x07\x62\x61seFee2\xac\x01\n\x05Query\x12\xa2\x01\n\rGetEipBaseFee\x12..osmosis.txfees.v1beta1.QueryEipBaseFeeRequest\x1a/.osmosis.txfees.v1beta1.QueryEipBaseFeeResponse\"0\x82\xd3\xe4\x93\x02*\x12(/osmosis/txfees/v1beta1/cur_eip_base_feeB\xf8\x01\n\x1a\x63om.osmosis.txfees.v1beta1B\nQueryProtoP\x01ZTgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/osmosis/types\xa2\x02\x03OTX\xaa\x02\x16Osmosis.Txfees.V1beta1\xca\x02\x16Osmosis\\Txfees\\V1beta1\xe2\x02\"Osmosis\\Txfees\\V1beta1\\GPBMetadata\xea\x02\x18Osmosis::Txfees::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.txfees.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.osmosis.txfees.v1beta1B\nQueryProtoP\001ZTgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/osmosis/types\242\002\003OTX\252\002\026Osmosis.Txfees.V1beta1\312\002\026Osmosis\\Txfees\\V1beta1\342\002\"Osmosis\\Txfees\\V1beta1\\GPBMetadata\352\002\030Osmosis::Txfees::V1beta1'
  _globals['_QUERYEIPBASEFEERESPONSE'].fields_by_name['base_fee']._loaded_options = None
  _globals['_QUERYEIPBASEFEERESPONSE'].fields_by_name['base_fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\017yaml:\"base_fee\"'
  _globals['_QUERY'].methods_by_name['GetEipBaseFee']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetEipBaseFee']._serialized_options = b'\202\323\344\223\002*\022(/osmosis/txfees/v1beta1/cur_eip_base_fee'
  _globals['_QUERYEIPBASEFEEREQUEST']._serialized_start=146
  _globals['_QUERYEIPBASEFEEREQUEST']._serialized_end=170
  _globals['_QUERYEIPBASEFEERESPONSE']._serialized_start=172
  _globals['_QUERYEIPBASEFEERESPONSE']._serialized_end=280
  _globals['_QUERY']._serialized_start=283
  _globals['_QUERY']._serialized_end=455
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/transfer.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ibc/applications/transfer/v1/transfer.proto\x12\x1cibc.applications.transfer.v1\"?\n\nDenomTrace\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1d\n\nbase_denom\x18\x02 \x01(\tR\tbaseDenom\"T\n\x06Params\x12!\n\x0csend_enabled\x18\x01 \x01(\x08R\x0bsendEnabled\x12\'\n\x0freceive_enabled\x18\x02 \x01(\x08R\x0ereceiveEnabledB\xfd\x01\n com.ibc.applications.transfer.v1B\rTransferProtoP\x01Z7github.com/cosmos/ibc-go/v8/modules/apps/transfer/types\xa2\x02\x03IAT\xaa\x02\x1cIbc.Applications.Transfer.V1\xca\x02\x1cIbc\\Applications\\Transfer\\V1\xe2\x02(Ibc\\Applications\\Transfer\\V1\\GPBMetadata\xea\x02\x1fIbc::Applications::Transfer::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.transfer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.ibc.applications.transfer.v1B\rTransferProtoP\001Z7github.com/cosmos/ibc-go/v8/modules/apps/transfer/types\242\002\003IAT\252\002\034Ibc.Applications.Transfer.V1\312\002\034Ibc\\Applications\\Transfer\\V1\342\002(Ibc\\Applications\\Transfer\\V1\\GPBMetadata\352\002\037Ibc::Applications::Transfer::V1'
  _globals['_DENOMTRACE']._serialized_start=77
  _globals['_DENOMTRACE']._serialized_end=140
  _globals['_PARAMS']._serialized_start=142
  _globals['_PARAMS']._serialized_end=226
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos_proto/cosmos.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63osmos_proto/cosmos.proto\x12\x0c\x63osmos_proto\x1a google/protobuf/descriptor.proto\"K\n\x13InterfaceDescriptor\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"\x81\x01\n\x10ScalarDescriptor\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x37\n\nfield_type\x18\x03 \x03(\x0e\x32\x18.cosmos_proto.ScalarTypeR\tfieldType*X\n\nScalarType\x12\x1b\n\x17SCALAR_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12SCALAR_TYPE_STRING\x10\x01\x12\x15\n\x11SCALAR_TYPE_BYTES\x10\x02:H\n\x0fmethod_added_in\x12\x1e.google.protobuf.MethodOptions\x18\xc9\xd6\x05 \x01(\tR\rmethodAddedIn:T\n\x14implements_interface\x12\x1f.google.protobuf.MessageOptions\x18\xc9\xd6\x05 \x03(\tR\x13implementsInterface:K\n\x10message_added_in\x12\x1f.google.protobuf.MessageOptions\x18\xca\xd6\x05 \x01(\tR\x0emessageAddedIn:L\n\x11\x61\x63\x63\x65pts_interface\x12\x1d.google.protobuf.FieldOptions\x18\xc9\xd6\x05 \x01(\tR\x10\x61\x63\x63\x65ptsInterface:7\n\x06scalar\x12\x1d.google.protobuf.FieldOptions\x18\xca\xd6\x05 \x01(\tR\x06scalar:E\n\x0e\x66ield_added_in\x12\x1d.google.protobuf.FieldOptions\x18\xcb\xd6\x05 \x01(\tR\x0c\x66ieldAddedIn:n\n\x11\x64\x65\x63lare_interface\x12\x1c.google.protobuf.FileOptions\x18\xbd\xb3\x30 \x03(\x0b\x32!.cosmos_proto.InterfaceDescriptorR\x10\x64\x65\x63lareInterface:e\n\x0e\x64\x65\x63lare_scalar\x12\x1c.google.protobuf.FileOptions\x18\xbe\xb3\x30 \x03(\x0b\x32\x1e.cosmos_proto.ScalarDescriptorR\rdeclareScalar:B\n\rfile_added_in\x12\x1c.google.protobuf.FileOptions\x18\xbf\xb3\x30 \x01(\tR\x0b\x66ileAddedInB\x98\x01\n\x10\x63om.cosmos_protoB\x0b\x43osmosProtoP\x01Z+github.com/cosmos/cosmos-proto;cosmos_proto\xa2\x02\x03\x43XX\xaa\x02\x0b\x43osmosProto\xca\x02\x0b\x43osmosProto\xe2\x02\x17\x43osmosProto\\GPBMetadata\xea\x02\x0b\x43osmosProtob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos_proto.cosmos_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.cosmos_protoB\013CosmosProtoP\001Z+github.com/cosmos/cosmos-proto;cosmos_proto\242\002\003CXX\252\002\013CosmosProto\312\002\013CosmosProto\342\002\027CosmosProto\\GPBMetadata\352\002\013CosmosProto'
  _globals['_SCALARTYPE']._serialized_start=286
  _globals['_SCALARTYPE']._serialized_end=374
  _globals['_INTERFACEDESCRIPTOR']._serialized_start=77
  _globals['_INTERFACEDESCRIPTOR']._serialized_end=152
  _globals['_SCALARDESCRIPTOR']._serialized_start=155
  _globals['_SCALARDESCRIPTOR']._serialized_end=284
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/bank/v1beta1/events.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"_\n\x10\x45ventSetBalances\x12K\n\x0f\x62\x61lance_updates\x18\x01 \x03(\x0b\x32\".cosmos.bank.v1beta1.BalanceUpdateR\x0e\x62\x61lanceUpdates\"}\n\rBalanceUpdate\x12\x12\n\x04\x61\x64\x64r\x18\x01 \x01(\x0cR\x04\x61\x64\x64r\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\x0cR\x05\x64\x65nom\x12\x42\n\x03\x61mt\x18\x03 \x01(\tB0\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01R\x03\x61mtB\xbf\x01\n\x17\x63om.cosmos.bank.v1beta1B\x0b\x45ventsProtoP\x01Z)github.com/cosmos/cosmos-sdk/x/bank/types\xa2\x02\x03\x43\x42X\xaa\x02\x13\x43osmos.Bank.V1beta1\xca\x02\x13\x43osmos\\Bank\\V1beta1\xe2\x02\x1f\x43osmos\\Bank\\V1beta1\\GPBMetadata\xea\x02\x15\x43osmos::Bank::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.bank.v1beta1B\013EventsProtoP\001Z)github.com/cosmos/cosmos-sdk/x/bank/types\242\002\003CBX\252\002\023Cosmos.Bank.V1beta1\312\002\023Cosmos\\Bank\\V1beta1\342\002\037Cosmos\\Bank\\V1beta1\\GPBMetadata\352\002\025Cosmos::Bank::V1beta1'
  _globals['_BALANCEUPDATE'].fields_by_name['amt']._loaded_options = None
  _globals['_BALANCEUPDATE'].fields_by_name['amt']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_EVENTSETBALANCES']._serialized_start=125
  _globals['_EVENTSETBALANCES']._serialized_end=220
  _globals['_BALANCEUPDATE']._serialized_start=222
  _globals['_BALANCEUPDATE']._serialized_end=347
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_exchange_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_exchange_rpc.proto\x12\x16injective_exchange_rpc\"\"\n\x0cGetTxRequest\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\"\xd3\x01\n\rGetTxResponse\x12\x17\n\x07tx_hash\x18\x01 \x01(\tR\x06txHash\x12\x16\n\x06height\x18\x02 \x01(\x12R\x06height\x12\x14\n\x05index\x18\x03 \x01(\rR\x05index\x12\x1c\n\tcodespace\x18\x04 \x01(\tR\tcodespace\x12\x12\n\x04\x63ode\x18\x05 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\x12\x17\n\x07raw_log\x18\x07 \x01(\tR\x06rawLog\x12\x1c\n\ttimestamp\x18\x08 \x01(\tR\ttimestamp\"\x9d\x02\n\x10PrepareTxRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\x04R\x07\x63hainId\x12%\n\x0esigner_address\x18\x02 \x01(\tR\rsignerAddress\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\x12\x12\n\x04memo\x18\x04 \x01(\tR\x04memo\x12%\n\x0etimeout_height\x18\x05 \x01(\x04R\rtimeoutHeight\x12\x35\n\x03\x66\x65\x65\x18\x06 \x01(\x0b\x32#.injective_exchange_rpc.CosmosTxFeeR\x03\x66\x65\x65\x12\x12\n\x04msgs\x18\x07 \x03(\x0cR\x04msgs\x12%\n\x0e\x65ip712_wrapper\x18\x08 \x01(\tR\reip712Wrapper\"|\n\x0b\x43osmosTxFee\x12\x38\n\x05price\x18\x01 \x03(\x0b\x32\".injective_exchange_rpc.CosmosCoinR\x05price\x12\x10\n\x03gas\x18\x02 \x01(\x04R\x03gas\x12!\n\x0c\x64\x65legate_fee\x18\x03 \x01(\x08R\x0b\x64\x65legateFee\":\n\nCosmosCoin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\"\xc3\x01\n\x11PrepareTxResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\tR\x04\x64\x61ta\x12\x1a\n\x08sequence\x18\x02 \x01(\x04R\x08sequence\x12\x1b\n\tsign_mode\x18\x03 \x01(\tR\x08signMode\x12 \n\x0cpub_key_type\x18\x04 \x01(\tR\npubKeyType\x12\x1b\n\tfee_payer\x18\x05 \x01(\tR\x08\x66\x65\x65Payer\x12\"\n\rfee_payer_sig\x18\x06 \x01(\tR\x0b\x66\x65\x65PayerSig\"\xc8\x02\n\x14PrepareEip712Request\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\x04R\x07\x63hainId\x12%\n\x0esigner_address\x18\x02 \x01(\tR\rsignerAddress\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\x12%\n\x0e\x61\x63\x63ount_number\x18\x04 \x01(\x04R\raccountNumber\x12\x12\n\x04memo\x18\x05 \x01(\tR\x04memo\x12%\n\x0etimeout_height\x18\x06 \x01(\x04R\rtimeoutHeight\x12\x35\n\x03\x66\x65\x65\x18\x07 \x01(\x0b\x32#.injective_exchange_rpc.CosmosTxFeeR\x03\x66\x65\x65\x12\x12\n\x04msgs\x18\x08 \x03(\x0cR\x04msgs\x12%\n\x0e\x65ip712_wrapper\x18\t \x01(\tR\reip712Wrapper\"+\n\x15PrepareEip712Response\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\tR\x04\x64\x61ta\"\x85\x02\n\x12\x42roadcastTxRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\x04R\x07\x63hainId\x12\x0e\n\x02tx\x18\x02 \x01(\x0cR\x02tx\x12\x12\n\x04msgs\x18\x03 \x03(\x0cR\x04msgs\x12=\n\x07pub_key\x18\x04 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKeyR\x06pubKey\x12\x1c\n\tsignature\x18\x05 \x01(\tR\tsignature\x12\x1b\n\tfee_payer\x18\x06 \x01(\tR\x08\x66\x65\x65Payer\x12\"\n\rfee_payer_sig\x18\x07 \x01(\tR\x0b\x66\x65\x65PayerSig\x12\x12\n\x04mode\x18\x08 \x01(\tR\x04mode\"4\n\x0c\x43osmosPubKey\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"\xd9\x01\n\x13\x42roadcastTxResponse\x12\x17\n\x07tx_hash\x18\x01 \x01(\tR\x06txHash\x12\x16\n\x06height\x18\x02 \x01(\x12R\x06height\x12\x14\n\x05index\x18\x03 \x01(\rR\x05index\x12\x1c\n\tcodespace\x18\x04 \x01(\tR\tcodespace\x12\x12\n\x04\x63ode\x18\x05 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\x12\x17\n\x07raw_log\x18\x07 \x01(\tR\x06rawLog\x12\x1c\n\ttimestamp\x18\x08 \x01(\tR\ttimestamp\"\xe0\x01\n\x16PrepareCosmosTxRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\x04R\x07\x63hainId\x12%\n\x0esender_address\x18\x02 \x01(\tR\rsenderAddress\x12\x12\n\x04memo\x18\x03 \x01(\tR\x04memo\x12%\n\x0etimeout_height\x18\x04 \x01(\x04R\rtimeoutHeight\x12\x35\n\x03\x66\x65\x65\x18\x05 \x01(\x0b\x32#.injective_exchange_rpc.CosmosTxFeeR\x03\x66\x65\x65\x12\x12\n\x04msgs\x18\x06 \x03(\x0cR\x04msgs\"\xfa\x01\n\x17PrepareCosmosTxResponse\x12\x0e\n\x02tx\x18\x01 \x01(\x0cR\x02tx\x12\x1b\n\tsign_mode\x18\x02 \x01(\tR\x08signMode\x12 \n\x0cpub_key_type\x18\x03 \x01(\tR\npubKeyType\x12\x1b\n\tfee_payer\x18\x04 \x01(\tR\x08\x66\x65\x65Payer\x12\"\n\rfee_payer_sig\x18\x05 \x01(\tR\x0b\x66\x65\x65PayerSig\x12O\n\x11\x66\x65\x65_payer_pub_key\x18\x06 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKeyR\x0e\x66\x65\x65PayerPubKey\"\xae\x01\n\x18\x42roadcastCosmosTxRequest\x12\x0e\n\x02tx\x18\x01 \x01(\x0cR\x02tx\x12=\n\x07pub_key\x18\x02 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKeyR\x06pubKey\x12\x1c\n\tsignature\x18\x03 \x01(\tR\tsignature\x12%\n\x0esender_address\x18\x04 \x01(\tR\rsenderAddress\"\xdf\x01\n\x19\x42roadcastCosmosTxResponse\x12\x17\n\x07tx_hash\x18\x01 \x01(\tR\x06txHash\x12\x16\n\x06height\x18\x02 \x01(\x12R\x06height\x12\x14\n\x05index\x18\x03 \x01(\rR\x05index\x12\x1c\n\tcodespace\x18\x04 \x01(\tR\tcodespace\x12\x12\n\x04\x63ode\x18\x05 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\x12\x17\n\x07raw_log\x18\x07 \x01(\tR\x06rawLog\x12\x1c\n\ttimestamp\x18\x08 \x01(\tR\ttimestamp\"\x14\n\x12GetFeePayerRequest\"\x83\x01\n\x13GetFeePayerResponse\x12\x1b\n\tfee_payer\x18\x01 \x01(\tR\x08\x66\x65\x65Payer\x12O\n\x11\x66\x65\x65_payer_pub_key\x18\x02 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKeyR\x0e\x66\x65\x65PayerPubKey2\xfa\x05\n\x14InjectiveExchangeRPC\x12T\n\x05GetTx\x12$.injective_exchange_rpc.GetTxRequest\x1a%.injective_exchange_rpc.GetTxResponse\x12`\n\tPrepareTx\x12(.injective_exchange_rpc.PrepareTxRequest\x1a).injective_exchange_rpc.PrepareTxResponse\x12l\n\rPrepareEip712\x12,.injective_exchange_rpc.PrepareEip712Request\x1a-.injective_exchange_rpc.PrepareEip712Response\x12\x66\n\x0b\x42roadcastTx\x12*.injective_exchange_rpc.BroadcastTxRequest\x1a+.injective_exchange_rpc.BroadcastTxResponse\x12r\n\x0fPrepareCosmosTx\x12..injective_exchange_rpc.PrepareCosmosTxRequest\x1a/.injective_exchange_rpc.PrepareCosmosTxResponse\x12x\n\x11\x42roadcastCosmosTx\x12\x30.injective_exchange_rpc.BroadcastCosmosTxRequest\x1a\x31.injective_exchange_rpc.BroadcastCosmosTxResponse\x12\x66\n\x0bGetFeePayer\x12*.injective_exchange_rpc.GetFeePayerRequest\x1a+.injective_exchange_rpc.GetFeePayerResponseB\xc2\x01\n\x1a\x63om.injective_exchange_rpcB\x19InjectiveExchangeRpcProtoP\x01Z\x19/injective_exchange_rpcpb\xa2\x02\x03IXX\xaa\x02\x14InjectiveExchangeRpc\xca\x02\x14InjectiveExchangeRpc\xe2\x02 InjectiveExchangeRpc\\GPBMetadata\xea\x02\x14InjectiveExchangeRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_exchange_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.injective_exchange_rpcB\031InjectiveExchangeRpcProtoP\001Z\031/injective_exchange_rpcpb\242\002\003IXX\252\002\024InjectiveExchangeRpc\312\002\024InjectiveExchangeRpc\342\002 InjectiveExchangeRpc\\GPBMetadata\352\002\024InjectiveExchangeRpc'
  _globals['_GETTXREQUEST']._serialized_start=65
  _globals['_GETTXREQUEST']._serialized_end=99
  _globals['_GETTXRESPONSE']._serialized_start=102
  _globals['_GETTXRESPONSE']._serialized_end=313
  _globals['_PREPARETXREQUEST']._serialized_start=316
  _globals['_PREPARETXREQUEST']._serialized_end=601
  _globals['_COSMOSTXFEE']._serialized_start=603
  _globals['_COSMOSTXFEE']._serialized_end=727
  _globals['_COSMOSCOIN']._serialized_start=729
  _globals['_COSMOSCOIN']._serialized_end=787
  _globals['_PREPARETXRESPONSE']._serialized_start=790
  _globals['_PREPARETXRESPONSE']._serialized_end=985
  _globals['_PREPAREEIP712REQUEST']._serialized_start=988
  _globals['_PREPAREEIP712REQUEST']._serialized_end=1316
  _globals['_PREPAREEIP712RESPONSE']._serialized_start=1318
  _globals['_PREPAREEIP712RESPONSE']._serialized_end=1361
  _globals['_BROADCASTTXREQUEST']._serialized_start=1364
  _globals['_BROADCASTTXREQUEST']._serialized_end=1625
  _globals['_COSMOSPUBKEY']._serialized_start=1627
  _globals['_COSMOSPUBKEY']._serialized_end=1679
  _globals['_BROADCASTTXRESPONSE']._serialized_start=1682
  _globals['_BROADCASTTXRESPONSE']._serialized_end=1899
  _globals['_PREPARECOSMOSTXREQUEST']._serialized_start=1902
  _globals['_PREPARECOSMOSTXREQUEST']._serialized_end=2126
  _globals['_PREPARECOSMOSTXRESPONSE']._serialized_start=2129
  _globals['_PREPARECOSMOSTXRESPONSE']._serialized_end=2379
  _globals['_BROADCASTCOSMOSTXREQUEST']._serialized_start=2382
  _globals['_BROADCASTCOSMOSTXREQUEST']._serialized_end=2556
  _globals['_BROADCASTCOSMOSTXRESPONSE']._serialized_start=2559
  _globals['_BROADCASTCOSMOSTXRESPONSE']._serialized_end=2782
  _globals['_GETFEEPAYERREQUEST']._serialized_start=2784
  _globals['_GETFEEPAYERREQUEST']._serialized_end=2804
  _globals['_GETFEEPAYERRESPONSE']._serialized_start=2807
  _globals['_GETFEEPAYERRESPONSE']._serialized_end=2938
  _globals['_INJECTIVEEXCHANGERPC']._serialized_start=2941
  _globals['_INJECTIVEEXCHANGERPC']._serialized_end=3703
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_trading_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$exchange/injective_trading_rpc.proto\x12\x15injective_trading_rpc\"\x9c\x04\n\x1cListTradingStrategiesRequest\x12\x14\n\x05state\x18\x01 \x01(\tR\x05state\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x04 \x01(\tR\x0e\x61\x63\x63ountAddress\x12+\n\x11pending_execution\x18\x05 \x01(\x08R\x10pendingExecution\x12\x1d\n\nstart_time\x18\x06 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x07 \x01(\x12R\x07\x65ndTime\x12\x14\n\x05limit\x18\x08 \x01(\x11R\x05limit\x12\x12\n\x04skip\x18\t \x01(\x04R\x04skip\x12#\n\rstrategy_type\x18\n \x03(\tR\x0cstrategyType\x12\x1f\n\x0bmarket_type\x18\x0b \x01(\tR\nmarketType\x12,\n\x12last_executed_time\x18\x0c \x01(\x12R\x10lastExecutedTime\x12\x19\n\x08with_tvl\x18\r \x01(\x08R\x07withTvl\x12\x30\n\x14is_trailing_strategy\x18\x0e \x01(\x08R\x12isTrailingStrategy\x12)\n\x10with_performance\x18\x0f \x01(\x08R\x0fwithPerformance\"\x9e\x01\n\x1dListTradingStrategiesResponse\x12\x46\n\nstrategies\x18\x01 \x03(\x0b\x32&.injective_trading_rpc.TradingStrategyR\nstrategies\x12\x35\n\x06paging\x18\x02 \x01(\x0b\x32\x1d.injective_trading_rpc.PagingR\x06paging\"\xf6\x11\n\x0fTradingStrategy\x12\x14\n\x05state\x18\x01 \x01(\tR\x05state\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x04 \x01(\tR\x0e\x61\x63\x63ountAddress\x12)\n\x10\x63ontract_address\x18\x05 \x01(\tR\x0f\x63ontractAddress\x12\'\n\x0f\x65xecution_price\x18\x06 \x01(\tR\x0e\x65xecutionPrice\x12#\n\rbase_quantity\x18\x07 \x01(\tR\x0c\x62\x61seQuantity\x12%\n\x0equote_quantity\x18\x14 \x01(\tR\rquoteQuantity\x12\x1f\n\x0blower_bound\x18\x08 \x01(\tR\nlowerBound\x12\x1f\n\x0bupper_bound\x18\t \x01(\tR\nupperBound\x12\x1b\n\tstop_loss\x18\n \x01(\tR\x08stopLoss\x12\x1f\n\x0btake_profit\x18\x0b \x01(\tR\ntakeProfit\x12\x19\n\x08swap_fee\x18\x0c \x01(\tR\x07swapFee\x12!\n\x0c\x62\x61se_deposit\x18\x11 \x01(\tR\x0b\x62\x61seDeposit\x12#\n\rquote_deposit\x18\x12 \x01(\tR\x0cquoteDeposit\x12(\n\x10market_mid_price\x18\x13 \x01(\tR\x0emarketMidPrice\x12>\n\x1bsubscription_quote_quantity\x18\x15 \x01(\tR\x19subscriptionQuoteQuantity\x12<\n\x1asubscription_base_quantity\x18\x16 \x01(\tR\x18subscriptionBaseQuantity\x12\x31\n\x15number_of_grid_levels\x18\x17 \x01(\tR\x12numberOfGridLevels\x12<\n\x1bshould_exit_with_quote_only\x18\x18 \x01(\x08R\x17shouldExitWithQuoteOnly\x12\x1f\n\x0bstop_reason\x18\x19 \x01(\tR\nstopReason\x12+\n\x11pending_execution\x18\x1a \x01(\x08R\x10pendingExecution\x12%\n\x0e\x63reated_height\x18\r \x01(\x12R\rcreatedHeight\x12%\n\x0eremoved_height\x18\x0e \x01(\x12R\rremovedHeight\x12\x1d\n\ncreated_at\x18\x0f \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x10 \x01(\x12R\tupdatedAt\x12\x1b\n\texit_type\x18\x1b \x01(\tR\x08\x65xitType\x12K\n\x10stop_loss_config\x18\x1c \x01(\x0b\x32!.injective_trading_rpc.ExitConfigR\x0estopLossConfig\x12O\n\x12take_profit_config\x18\x1d \x01(\x0b\x32!.injective_trading_rpc.ExitConfigR\x10takeProfitConfig\x12#\n\rstrategy_type\x18\x1e \x01(\tR\x0cstrategyType\x12)\n\x10\x63ontract_version\x18\x1f \x01(\tR\x0f\x63ontractVersion\x12#\n\rcontract_name\x18  \x01(\tR\x0c\x63ontractName\x12\x1f\n\x0bmarket_type\x18! \x01(\tR\nmarketType\x12(\n\x10last_executed_at\x18\" \x01(\x12R\x0elastExecutedAt\x12$\n\x0etrail_up_price\x18# \x01(\tR\x0ctrailUpPrice\x12(\n\x10trail_down_price\x18$ \x01(\tR\x0etrailDownPrice\x12(\n\x10trail_up_counter\x18% \x01(\x12R\x0etrailUpCounter\x12,\n\x12trail_down_counter\x18& \x01(\x12R\x10trailDownCounter\x12\x10\n\x03tvl\x18\' \x01(\tR\x03tvl\x12\x10\n\x03pnl\x18( \x01(\tR\x03pnl\x12\x19\n\x08pnl_perc\x18) \x01(\tR\x07pnlPerc\x12$\n\x0epnl_updated_at\x18* \x01(\x12R\x0cpnlUpdatedAt\x12 \n\x0bperformance\x18+ \x01(\tR\x0bperformance\x12\x10\n\x03roi\x18, \x01(\tR\x03roi\x12,\n\x12initial_base_price\x18- \x01(\tR\x10initialBasePrice\x12.\n\x13initial_quote_price\x18. \x01(\tR\x11initialQuotePrice\x12,\n\x12\x63urrent_base_price\x18/ \x01(\tR\x10\x63urrentBasePrice\x12.\n\x13\x63urrent_quote_price\x18\x30 \x01(\tR\x11\x63urrentQuotePrice\x12(\n\x10\x66inal_base_price\x18\x31 \x01(\tR\x0e\x66inalBasePrice\x12*\n\x11\x66inal_quote_price\x18\x32 \x01(\tR\x0f\x66inalQuotePrice\x12G\n\nfinal_data\x18\x33 \x01(\x0b\x32(.injective_trading_rpc.StrategyFinalDataR\tfinalData\x12!\n\x0cmargin_ratio\x18\x34 \x01(\tR\x0bmarginRatio\x12\x30\n\x14lower_trailing_bound\x18\x35 \x01(\tR\x12lowerTrailingBound\x12\x30\n\x14upper_trailing_bound\x18\x36 \x01(\tR\x12upperTrailingBound\x12&\n\x0fnew_upper_bound\x18\x37 \x01(\tR\rnewUpperBound\x12&\n\x0fnew_lower_bound\x18\x38 \x01(\tR\rnewLowerBound\"H\n\nExitConfig\x12\x1b\n\texit_type\x18\x01 \x01(\tR\x08\x65xitType\x12\x1d\n\nexit_price\x18\x02 \x01(\tR\texitPrice\"\x83\x03\n\x11StrategyFinalData\x12.\n\x13initial_base_amount\x18\x01 \x01(\tR\x11initialBaseAmount\x12\x30\n\x14initial_quote_amount\x18\x02 \x01(\tR\x12initialQuoteAmount\x12*\n\x11\x66inal_base_amount\x18\x03 \x01(\tR\x0f\x66inalBaseAmount\x12,\n\x12\x66inal_quote_amount\x18\x04 \x01(\tR\x10\x66inalQuoteAmount\x12,\n\x12initial_base_price\x18\x05 \x01(\tR\x10initialBasePrice\x12.\n\x13initial_quote_price\x18\x06 \x01(\tR\x11initialQuotePrice\x12(\n\x10\x66inal_base_price\x18\x07 \x01(\tR\x0e\x66inalBasePrice\x12*\n\x11\x66inal_quote_price\x18\x08 \x01(\tR\x0f\x66inalQuotePrice\"\x86\x01\n\x06Paging\x12\x14\n\x05total\x18\x01 \x01(\x12R\x05total\x12\x12\n\x04\x66rom\x18\x02 \x01(\x11R\x04\x66rom\x12\x0e\n\x02to\x18\x03 \x01(\x11R\x02to\x12.\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12R\x11\x63ountBySubaccount\x12\x12\n\x04next\x18\x05 \x03(\tR\x04next\"\x18\n\x16GetTradingStatsRequest\"\xf4\x01\n\x17GetTradingStatsResponse\x12:\n\x19\x61\x63tive_trading_strategies\x18\x01 \x01(\x04R\x17\x61\x63tiveTradingStrategies\x12G\n total_trading_strategies_created\x18\x02 \x01(\x04R\x1dtotalTradingStrategiesCreated\x12\x1b\n\ttotal_tvl\x18\x03 \x01(\tR\x08totalTvl\x12\x37\n\x07markets\x18\x04 \x03(\x0b\x32\x1d.injective_trading_rpc.MarketR\x07markets\"a\n\x06Market\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12:\n\x19\x61\x63tive_trading_strategies\x18\x02 \x01(\x04R\x17\x61\x63tiveTradingStrategies\"a\n\x15StreamStrategyRequest\x12+\n\x11\x61\x63\x63ount_addresses\x18\x01 \x03(\tR\x10\x61\x63\x63ountAddresses\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"\x89\x01\n\x16StreamStrategyResponse\x12Q\n\x10trading_strategy\x18\x01 \x01(\x0b\x32&.injective_trading_rpc.TradingStrategyR\x0ftradingStrategy\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp2\xfd\x02\n\x13InjectiveTradingRPC\x12\x82\x01\n\x15ListTradingStrategies\x12\x33.injective_trading_rpc.ListTradingStrategiesRequest\x1a\x34.injective_trading_rpc.ListTradingStrategiesResponse\x12p\n\x0fGetTradingStats\x12-.injective_trading_rpc.GetTradingStatsRequest\x1a..injective_trading_rpc.GetTradingStatsResponse\x12o\n\x0eStreamStrategy\x12,.injective_trading_rpc.StreamStrategyRequest\x1a-.injective_trading_rpc.StreamStrategyResponse0\x01\x42\xbb\x01\n\x19\x63om.injective_trading_rpcB\x18InjectiveTradingRpcProtoP\x01Z\x18/injective_trading_rpcpb\xa2\x02\x03IXX\xaa\x02\x13InjectiveTradingRpc\xca\x02\x13InjectiveTradingRpc\xe2\x02\x1fInjectiveTradingRpc\\GPBMetadata\xea\x02\x13InjectiveTradingRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_trading_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective_trading_rpcB\030InjectiveTradingRpcProtoP\001Z\030/injective_trading_rpcpb\242\002\003IXX\252\002\023InjectiveTradingRpc\312\002\023InjectiveTradingRpc\342\002\037InjectiveTradingRpc\\GPBMetadata\352\002\023InjectiveTradingRpc'
  _globals['_LISTTRADINGSTRATEGIESREQUEST']._serialized_start=64
  _globals['_LISTTRADINGSTRATEGIESREQUEST']._serialized_end=604
  _globals['_LISTTRADINGSTRATEGIESRESPONSE']._serialized_start=607
  _globals['_LISTTRADINGSTRATEGIESRESPONSE']._serialized_end=765
  _globals['_TRADINGSTRATEGY']._serialized_start=768
  _globals['_TRADINGSTRATEGY']._serialized_end=3062
  _globals['_EXITCONFIG']._serialized_start=3064
  _globals['_EXITCONFIG']._serialized_end=3136
  _globals['_STRATEGYFINALDATA']._serialized_start=3139
  _globals['_STRATEGYFINALDATA']._serialized_end=3526
  _globals['_PAGING']._serialized_start=3529
  _globals['_PAGING']._serialized_end=3663
  _globals['_GETTRADINGSTATSREQUEST']._serialized_start=3665
  _globals['_GETTRADINGSTATSREQUEST']._serialized_end=3689
  _globals['_GETTRADINGSTATSRESPONSE']._serialized_start=3692
  _globals['_GETTRADINGSTATSRESPONSE']._serialized_end=3936
  _globals['_MARKET']._serialized_start=3938
  _globals['_MARKET']._serialized_end=4035
  _globals['_STREAMSTRATEGYREQUEST']._serialized_start=4037
  _globals['_STREAMSTRATEGYREQUEST']._serialized_end=4134
  _globals['_STREAMSTRATEGYRESPONSE']._serialized_start=4137
  _globals['_STREAMSTRATEGYRESPONSE']._serialized_end=4274
  _globals['_INJECTIVETRADINGRPC']._serialized_start=4277
  _globals['_INJECTIVETRADINGRPC']._serialized_end=4658
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/version/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/version/v1/types.proto\x12\x13\x63ometbft.version.v1\x1a\x14gogoproto/gogo.proto\"=\n\x03\x41pp\x12\x1a\n\x08protocol\x18\x01 \x01(\x04R\x08protocol\x12\x1a\n\x08software\x18\x02 \x01(\tR\x08software\"9\n\tConsensus\x12\x14\n\x05\x62lock\x18\x01 \x01(\x04R\x05\x62lock\x12\x10\n\x03\x61pp\x18\x02 \x01(\x04R\x03\x61pp:\x04\xe8\xa0\x1f\x01\x42\xc9\x01\n\x17\x63om.cometbft.version.v1B\nTypesProtoP\x01Z4github.com/cometbft/cometbft/api/cometbft/version/v1\xa2\x02\x03\x43VX\xaa\x02\x13\x43ometbft.Version.V1\xca\x02\x13\x43ometbft\\Version\\V1\xe2\x02\x1f\x43ometbft\\Version\\V1\\GPBMetadata\xea\x02\x15\x43ometbft::Version::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.version.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cometbft.version.v1B\nTypesProtoP\001Z4github.com/cometbft/cometbft/api/cometbft/version/v1\242\002\003CVX\252\002\023Cometbft.Version.V1\312\002\023Cometbft\\Version\\V1\342\002\037Cometbft\\Version\\V1\\GPBMetadata\352\002\025Cometbft::Version::V1'
  _globals['_CONSENSUS']._loaded_options = None
  _globals['_CONSENSUS']._serialized_options = b'\350\240\037\001'
  _globals['_APP']._serialized_start=78
  _globals['_APP']._serialized_end=139
  _globals['_CONSENSUS']._serialized_start=141
  _globals['_CONSENSUS']._serialized_end=198
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/exchange/v1beta1/events.proto\x12\x1ainjective.exchange.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a)injective/exchange/v1beta1/exchange.proto\"\xdc\x01\n\x17\x45ventBatchSpotExecution\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x15\n\x06is_buy\x18\x02 \x01(\x08R\x05isBuy\x12O\n\rexecutionType\x18\x03 \x01(\x0e\x32).injective.exchange.v1beta1.ExecutionTypeR\rexecutionType\x12<\n\x06trades\x18\x04 \x03(\x0b\x32$.injective.exchange.v1beta1.TradeLogR\x06trades\"\xe7\x02\n\x1d\x45ventBatchDerivativeExecution\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x15\n\x06is_buy\x18\x02 \x01(\x08R\x05isBuy\x12%\n\x0eis_liquidation\x18\x03 \x01(\x08R\risLiquidation\x12R\n\x12\x63umulative_funding\x18\x04 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x11\x63umulativeFunding\x12O\n\rexecutionType\x18\x05 \x01(\x0e\x32).injective.exchange.v1beta1.ExecutionTypeR\rexecutionType\x12\x46\n\x06trades\x18\x06 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativeTradeLogR\x06trades\"\xc2\x02\n\x1d\x45ventLostFundsFromLiquidation\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\x0cR\x0csubaccountId\x12x\n\'lost_funds_from_available_during_payout\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\"lostFundsFromAvailableDuringPayout\x12\x65\n\x1dlost_funds_from_order_cancels\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x19lostFundsFromOrderCancels\"\x89\x01\n\x1c\x45ventBatchDerivativePosition\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12L\n\tpositions\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.SubaccountPositionR\tpositions\"\xbb\x01\n\x1b\x45ventDerivativeMarketPaused\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12!\n\x0csettle_price\x18\x02 \x01(\tR\x0bsettlePrice\x12.\n\x13total_missing_funds\x18\x03 \x01(\tR\x11totalMissingFunds\x12,\n\x12missing_funds_rate\x18\x04 \x01(\tR\x10missingFundsRate\"P\n\x19\x45ventSettledMarketBalance\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\"S\n\x1c\x45ventNotSettledMarketBalance\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\"\x8f\x01\n\x1b\x45ventMarketBeyondBankruptcy\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12!\n\x0csettle_price\x18\x02 \x01(\tR\x0bsettlePrice\x12\x30\n\x14missing_market_funds\x18\x03 \x01(\tR\x12missingMarketFunds\"\x88\x01\n\x18\x45ventAllPositionsHaircut\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12!\n\x0csettle_price\x18\x02 \x01(\tR\x0bsettlePrice\x12,\n\x12missing_funds_rate\x18\x03 \x01(\tR\x10missingFundsRate\"o\n\x1e\x45ventBinaryOptionsMarketUpdate\x12M\n\x06market\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.BinaryOptionsMarketB\x04\xc8\xde\x1f\x00R\x06market\"\xc9\x01\n\x12\x45ventNewSpotOrders\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12I\n\nbuy_orders\x18\x02 \x03(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrderR\tbuyOrders\x12K\n\x0bsell_orders\x18\x03 \x03(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrderR\nsellOrders\"\xdb\x01\n\x18\x45ventNewDerivativeOrders\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12O\n\nbuy_orders\x18\x02 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderR\tbuyOrders\x12Q\n\x0bsell_orders\x18\x03 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderR\nsellOrders\"{\n\x14\x45ventCancelSpotOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x46\n\x05order\x18\x02 \x01(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrderB\x04\xc8\xde\x1f\x00R\x05order\"]\n\x15\x45ventSpotMarketUpdate\x12\x44\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarketB\x04\xc8\xde\x1f\x00R\x06market\"\xa7\x02\n\x1a\x45ventPerpetualMarketUpdate\x12J\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarketB\x04\xc8\xde\x1f\x00R\x06market\x12i\n\x15perpetual_market_info\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x01R\x13perpetualMarketInfo\x12R\n\x07\x66unding\x18\x03 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x01R\x07\x66unding\"\xe4\x01\n\x1e\x45ventExpiryFuturesMarketUpdate\x12J\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarketB\x04\xc8\xde\x1f\x00R\x06market\x12v\n\x1a\x65xpiry_futures_market_info\x18\x03 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x01R\x17\x65xpiryFuturesMarketInfo\"\xcc\x02\n!EventPerpetualMarketFundingUpdate\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12R\n\x07\x66unding\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00R\x07\x66unding\x12*\n\x11is_hourly_funding\x18\x03 \x01(\x08R\x0fisHourlyFunding\x12\x46\n\x0c\x66unding_rate\x18\x04 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0b\x66undingRate\x12\x42\n\nmark_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tmarkPrice\"\x97\x01\n\x16\x45ventSubaccountDeposit\x12\x1f\n\x0bsrc_address\x18\x01 \x01(\tR\nsrcAddress\x12#\n\rsubaccount_id\x18\x02 \x01(\x0cR\x0csubaccountId\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"\x98\x01\n\x17\x45ventSubaccountWithdraw\x12#\n\rsubaccount_id\x18\x01 \x01(\x0cR\x0csubaccountId\x12\x1f\n\x0b\x64st_address\x18\x02 \x01(\tR\ndstAddress\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"\xb1\x01\n\x1e\x45ventSubaccountBalanceTransfer\x12*\n\x11src_subaccount_id\x18\x01 \x01(\tR\x0fsrcSubaccountId\x12*\n\x11\x64st_subaccount_id\x18\x02 \x01(\tR\x0f\x64stSubaccountId\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"m\n\x17\x45ventBatchDepositUpdate\x12R\n\x0f\x64\x65posit_updates\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.DepositUpdateR\x0e\x64\x65positUpdates\"\xc7\x01\n\x1b\x44\x65rivativeMarketOrderCancel\x12Z\n\x0cmarket_order\x18\x01 \x01(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrderB\x04\xc8\xde\x1f\x01R\x0bmarketOrder\x12L\n\x0f\x63\x61ncel_quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0e\x63\x61ncelQuantity\"\xa7\x02\n\x1a\x45ventCancelDerivativeOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12$\n\risLimitCancel\x18\x02 \x01(\x08R\risLimitCancel\x12W\n\x0blimit_order\x18\x03 \x01(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderB\x04\xc8\xde\x1f\x01R\nlimitOrder\x12m\n\x13market_order_cancel\x18\x04 \x01(\x0b\x32\x37.injective.exchange.v1beta1.DerivativeMarketOrderCancelB\x04\xc8\xde\x1f\x01R\x11marketOrderCancel\"g\n\x18\x45ventFeeDiscountSchedule\x12K\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountScheduleR\x08schedule\"\xe2\x01\n EventTradingRewardCampaignUpdate\x12Z\n\rcampaign_info\x18\x01 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfoR\x0c\x63\x61mpaignInfo\x12\x62\n\x15\x63\x61mpaign_reward_pools\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPoolR\x13\x63\x61mpaignRewardPools\"u\n\x1e\x45ventTradingRewardDistribution\x12S\n\x0f\x61\x63\x63ount_rewards\x18\x01 \x03(\x0b\x32*.injective.exchange.v1beta1.AccountRewardsR\x0e\x61\x63\x63ountRewards\"\xb5\x01\n\"EventNewConditionalDerivativeOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x41\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderR\x05order\x12\x12\n\x04hash\x18\x03 \x01(\x0cR\x04hash\x12\x1b\n\tis_market\x18\x04 \x01(\x08R\x08isMarket\"\x9f\x02\n%EventCancelConditionalDerivativeOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12$\n\risLimitCancel\x18\x02 \x01(\x08R\risLimitCancel\x12W\n\x0blimit_order\x18\x03 \x01(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderB\x04\xc8\xde\x1f\x01R\nlimitOrder\x12Z\n\x0cmarket_order\x18\x04 \x01(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrderB\x04\xc8\xde\x1f\x01R\x0bmarketOrder\"\xfb\x01\n&EventConditionalDerivativeOrderTrigger\x12\x1b\n\tmarket_id\x18\x01 \x01(\x0cR\x08marketId\x12&\n\x0eisLimitTrigger\x18\x02 \x01(\x08R\x0eisLimitTrigger\x12\x30\n\x14triggered_order_hash\x18\x03 \x01(\x0cR\x12triggeredOrderHash\x12*\n\x11placed_order_hash\x18\x04 \x01(\x0cR\x0fplacedOrderHash\x12.\n\x13triggered_order_cid\x18\x05 \x01(\tR\x11triggeredOrderCid\"l\n\x0e\x45ventOrderFail\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0cR\x07\x61\x63\x63ount\x12\x16\n\x06hashes\x18\x02 \x03(\x0cR\x06hashes\x12\x14\n\x05\x66lags\x18\x03 \x03(\rR\x05\x66lags\x12\x12\n\x04\x63ids\x18\x04 \x03(\tR\x04\x63ids\"\x94\x01\n+EventAtomicMarketOrderFeeMultipliersUpdated\x12\x65\n\x16market_fee_multipliers\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.MarketFeeMultiplierR\x14marketFeeMultipliers\"\xc2\x01\n\x14\x45ventOrderbookUpdate\x12N\n\x0cspot_updates\x18\x01 \x03(\x0b\x32+.injective.exchange.v1beta1.OrderbookUpdateR\x0bspotUpdates\x12Z\n\x12\x64\x65rivative_updates\x18\x02 \x03(\x0b\x32+.injective.exchange.v1beta1.OrderbookUpdateR\x11\x64\x65rivativeUpdates\"h\n\x0fOrderbookUpdate\x12\x10\n\x03seq\x18\x01 \x01(\x04R\x03seq\x12\x43\n\torderbook\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderbookR\torderbook\"\xae\x01\n\tOrderbook\x12\x1b\n\tmarket_id\x18\x01 \x01(\x0cR\x08marketId\x12@\n\nbuy_levels\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.LevelR\tbuyLevels\x12\x42\n\x0bsell_levels\x18\x03 \x03(\x0b\x32!.injective.exchange.v1beta1.LevelR\nsellLevels\"|\n\x18\x45ventGrantAuthorizations\x12\x18\n\x07granter\x18\x01 \x01(\tR\x07granter\x12\x46\n\x06grants\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.GrantAuthorizationR\x06grants\"\x81\x01\n\x14\x45ventGrantActivation\x12\x18\n\x07grantee\x18\x01 \x01(\tR\x07grantee\x12\x18\n\x07granter\x18\x02 \x01(\tR\x07granter\x12\x35\n\x06\x61mount\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x06\x61mount\"G\n\x11\x45ventInvalidGrant\x12\x18\n\x07grantee\x18\x01 \x01(\tR\x07grantee\x12\x18\n\x07granter\x18\x02 \x01(\tR\x07granter\"\xab\x01\n\x14\x45ventOrderCancelFail\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1d\n\norder_hash\x18\x03 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x04 \x01(\tR\x03\x63id\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scriptionB\x87\x02\n\x1e\x63om.injective.exchange.v1beta1B\x0b\x45ventsProtoP\x01ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types\xa2\x02\x03IEX\xaa\x02\x1aInjective.Exchange.V1beta1\xca\x02\x1aInjective\\Exchange\\V1beta1\xe2\x02&Injective\\Exchange\\V1beta1\\GPBMetadata\xea\x02\x1cInjective::Exchange::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.injective.exchange.v1beta1B\013EventsProtoP\001ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types\242\002\003IEX\252\002\032Injective.Exchange.V1beta1\312\002\032Injective\\Exchange\\V1beta1\342\002&Injective\\Exchange\\V1beta1\\GPBMetadata\352\002\034Injective::Exchange::V1beta1'
  _globals['_EVENTBATCHDERIVATIVEEXECUTION'].fields_by_name['cumulative_funding']._loaded_options = None
  _globals['_EVENTBATCHDERIVATIVEEXECUTION'].fields_by_name['cumulative_funding']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION'].fields_by_name['lost_funds_from_available_during_payout']._loaded_options = None
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION'].fields_by_name['lost_funds_from_available_during_payout']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION'].fields_by_name['lost_funds_from_order_cancels']._loaded_options = None
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION'].fields_by_name['lost_funds_from_order_cancels']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTBINARYOPTIONSMARKETUPDATE'].fields_by_name['market']._loaded_options = None
  _globals['_EVENTBINARYOPTIONSMARKETUPDATE'].fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTCANCELSPOTORDER'].fields_by_name['order']._loaded_options = None
  _globals['_EVENTCANCELSPOTORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTSPOTMARKETUPDATE'].fields_by_name['market']._loaded_options = None
  _globals['_EVENTSPOTMARKETUPDATE'].fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['market']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['perpetual_market_info']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['perpetual_market_info']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['funding']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETUPDATE'].fields_by_name['funding']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE'].fields_by_name['market']._loaded_options = None
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE'].fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE'].fields_by_name['expiry_futures_market_info']._loaded_options = None
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE'].fields_by_name['expiry_futures_market_info']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['funding']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['funding']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['funding_rate']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['funding_rate']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['mark_price']._loaded_options = None
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE'].fields_by_name['mark_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTSUBACCOUNTDEPOSIT'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTSUBACCOUNTDEPOSIT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTSUBACCOUNTWITHDRAW'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTSUBACCOUNTWITHDRAW'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTSUBACCOUNTBALANCETRANSFER'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTSUBACCOUNTBALANCETRANSFER'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_DERIVATIVEMARKETORDERCANCEL'].fields_by_name['market_order']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERCANCEL'].fields_by_name['market_order']._serialized_options = b'\310\336\037\001'
  _globals['_DERIVATIVEMARKETORDERCANCEL'].fields_by_name['cancel_quantity']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERCANCEL'].fields_by_name['cancel_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTCANCELDERIVATIVEORDER'].fields_by_name['limit_order']._loaded_options = None
  _globals['_EVENTCANCELDERIVATIVEORDER'].fields_by_name['limit_order']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTCANCELDERIVATIVEORDER'].fields_by_name['market_order_cancel']._loaded_options = None
  _globals['_EVENTCANCELDERIVATIVEORDER'].fields_by_name['market_order_cancel']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER'].fields_by_name['limit_order']._loaded_options = None
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER'].fields_by_name['limit_order']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER'].fields_by_name['market_order']._loaded_options = None
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER'].fields_by_name['market_order']._serialized_options = b'\310\336\037\001'
  _globals['_EVENTGRANTACTIVATION'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTGRANTACTIVATION'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTBATCHSPOTEXECUTION']._serialized_start=208
  _globals['_EVENTBATCHSPOTEXECUTION']._serialized_end=428
  _globals['_EVENTBATCHDERIVATIVEEXECUTION']._serialized_start=431
  _globals['_EVENTBATCHDERIVATIVEEXECUTION']._serialized_end=790
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION']._serialized_start=793
  _globals['_EVENTLOSTFUNDSFROMLIQUIDATION']._serialized_end=1115
  _globals['_EVENTBATCHDERIVATIVEPOSITION']._serialized_start=1118
  _globals['_EVENTBATCHDERIVATIVEPOSITION']._serialized_end=1255
  _globals['_EVENTDERIVATIVEMARKETPAUSED']._serialized_start=1258
  _globals['_EVENTDERIVATIVEMARKETPAUSED']._serialized_end=1445
  _globals['_EVENTSETTLEDMARKETBALANCE']._serialized_start=1447
  _globals['_EVENTSETTLEDMARKETBALANCE']._serialized_end=1527
  _globals['_EVENTNOTSETTLEDMARKETBALANCE']._serialized_start=1529
  _globals['_EVENTNOTSETTLEDMARKETBALANCE']._serialized_end=1612
  _globals['_EVENTMARKETBEYONDBANKRUPTCY']._serialized_start=1615
  _globals['_EVENTMARKETBEYONDBANKRUPTCY']._serialized_end=1758
  _globals['_EVENTALLPOSITIONSHAIRCUT']._serialized_start=1761
  _globals['_EVENTALLPOSITIONSHAIRCUT']._serialized_end=1897
  _globals['_EVENTBINARYOPTIONSMARKETUPDATE']._serialized_start=1899
  _globals['_EVENTBINARYOPTIONSMARKETUPDATE']._serialized_end=2010
  _globals['_EVENTNEWSPOTORDERS']._serialized_start=2013
  _globals['_EVENTNEWSPOTORDERS']._serialized_end=2214
  _globals['_EVENTNEWDERIVATIVEORDERS']._serialized_start=2217
  _globals['_EVENTNEWDERIVATIVEORDERS']._serialized_end=2436
  _globals['_EVENTCANCELSPOTORDER']._serialized_start=2438
  _globals['_EVENTCANCELSPOTORDER']._serialized_end=2561
  _globals['_EVENTSPOTMARKETUPDATE']._serialized_start=2563
  _globals['_EVENTSPOTMARKETUPDATE']._serialized_end=2656
  _globals['_EVENTPERPETUALMARKETUPDATE']._serialized_start=2659
  _globals['_EVENTPERPETUALMARKETUPDATE']._serialized_end=2954
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE']._serialized_start=2957
  _globals['_EVENTEXPIRYFUTURESMARKETUPDATE']._serialized_end=3185
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE']._serialized_start=3188
  _globals['_EVENTPERPETUALMARKETFUNDINGUPDATE']._serialized_end=3520
  _globals['_EVENTSUBACCOUNTDEPOSIT']._serialized_start=3523
  _globals['_EVENTSUBACCOUNTDEPOSIT']._serialized_end=3674
  _globals['_EVENTSUBACCOUNTWITHDRAW']._serialized_start=3677
  _globals['_EVENTSUBACCOUNTWITHDRAW']._serialized_end=3829
  _globals['_EVENTSUBACCOUNTBALANCETRANSFER']._serialized_start=3832
  _globals['_EVENTSUBACCOUNTBALANCETRANSFER']._serialized_end=4009
  _globals['_EVENTBATCHDEPOSITUPDATE']._serialized_start=4011
  _globals['_EVENTBATCHDEPOSITUPDATE']._serialized_end=4120
  _globals['_DERIVATIVEMARKETORDERCANCEL']._serialized_start=4123
  _globals['_DERIVATIVEMARKETORDERCANCEL']._serialized_end=4322
  _globals['_EVENTCANCELDERIVATIVEORDER']._serialized_start=4325
  _globals['_EVENTCANCELDERIVATIVEORDER']._serialized_end=4620
  _globals['_EVENTFEEDISCOUNTSCHEDULE']._serialized_start=4622
  _globals['_EVENTFEEDISCOUNTSCHEDULE']._serialized_end=4725
  _globals['_EVENTTRADINGREWARDCAMPAIGNUPDATE']._serialized_start=4728
  _globals['_EVENTTRADINGREWARDCAMPAIGNUPDATE']._serialized_end=4954
  _globals['_EVENTTRADINGREWARDDISTRIBUTION']._serialized_start=4956
  _globals['_EVENTTRADINGREWARDDISTRIBUTION']._serialized_end=5073
  _globals['_EVENTNEWCONDITIONALDERIVATIVEORDER']._serialized_start=5076
  _globals['_EVENTNEWCONDITIONALDERIVATIVEORDER']._serialized_end=5257
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER']._serialized_start=5260
  _globals['_EVENTCANCELCONDITIONALDERIVATIVEORDER']._serialized_end=5547
  _globals['_EVENTCONDITIONALDERIVATIVEORDERTRIGGER']._serialized_start=5550
  _globals['_EVENTCONDITIONALDERIVATIVEORDERTRIGGER']._serialized_end=5801
  _globals['_EVENTORDERFAIL']._serialized_start=5803
  _globals['_EVENTORDERFAIL']._serialized_end=5911
  _globals['_EVENTATOMICMARKETORDERFEEMULTIPLIERSUPDATED']._serialized_start=5914
  _globals['_EVENTATOMICMARKETORDERFEEMULTIPLIERSUPDATED']._serialized_end=6062
  _globals['_EVENTORDERBOOKUPDATE']._serialized_start=6065
  _globals['_EVENTORDERBOOKUPDATE']._serialized_end=6259
  _globals['_ORDERBOOKUPDATE']._serialized_start=6261
  _globals['_ORDERBOOKUPDATE']._serialized_end=6365
  _globals['_ORDERBOOK']._serialized_start=6368
  _globals['_ORDERBOOK']._serialized_end=6542
  _globals['_EVENTGRANTAUTHORIZATIONS']._serialized_start=6544
  _globals['_EVENTGRANTAUTHORIZATIONS']._serialized_end=6668
  _globals['_EVENTGRANTACTIVATION']._serialized_start=6671
  _globals['_EVENTGRANTACTIVATION']._serialized_end=6800
  _globals['_EVENTINVALIDGRANT']._serialized_start=6802
  _globals['_EVENTINVALIDGRANT']._serialized_end=6873
  _globals['_EVENTORDERCANCELFAIL']._serialized_start=6876
  _globals['_EVENTORDERCANCELFAIL']._serialized_end=7047
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.cosmos.authz.v1beta1 import query_pb2 as authz_query, query_pb2_grpc as authz_query_grpc
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcAuthZApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = authz_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_grants(
        self,
        granter: str,
        grantee: str,
        msg_type_url: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = authz_query.QueryGrantsRequest(
            granter=granter, grantee=grantee, msg_type_url=msg_type_url, pagination=pagination_request
        )

        response = await self._execute_call(call=self._stub.Grants, request=request)

        return response

    async def fetch_granter_grants(
        self,
        granter: str,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = authz_query.QueryGranterGrantsRequest(granter=granter, pagination=pagination_request)

        response = await self._execute_call(call=self._stub.GranterGrants, request=request)

        return response

    async def fetch_grantee_grants(
        self,
        grantee: str,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = authz_query.QueryGranteeGrantsRequest(grantee=grantee, pagination=pagination_request)

        response = await self._execute_call(call=self._stub.GranteeGrants, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/abci/v1/service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ometbft/abci/v1/service.proto\x12\x10\x63ometbft.abci.v1\x1a\x1c\x63ometbft/abci/v1/types.proto2\xc4\x0b\n\x0b\x41\x42\x43IService\x12\x45\n\x04\x45\x63ho\x12\x1d.cometbft.abci.v1.EchoRequest\x1a\x1e.cometbft.abci.v1.EchoResponse\x12H\n\x05\x46lush\x12\x1e.cometbft.abci.v1.FlushRequest\x1a\x1f.cometbft.abci.v1.FlushResponse\x12\x45\n\x04Info\x12\x1d.cometbft.abci.v1.InfoRequest\x1a\x1e.cometbft.abci.v1.InfoResponse\x12N\n\x07\x43heckTx\x12 .cometbft.abci.v1.CheckTxRequest\x1a!.cometbft.abci.v1.CheckTxResponse\x12H\n\x05Query\x12\x1e.cometbft.abci.v1.QueryRequest\x1a\x1f.cometbft.abci.v1.QueryResponse\x12K\n\x06\x43ommit\x12\x1f.cometbft.abci.v1.CommitRequest\x1a .cometbft.abci.v1.CommitResponse\x12T\n\tInitChain\x12\".cometbft.abci.v1.InitChainRequest\x1a#.cometbft.abci.v1.InitChainResponse\x12`\n\rListSnapshots\x12&.cometbft.abci.v1.ListSnapshotsRequest\x1a\'.cometbft.abci.v1.ListSnapshotsResponse\x12`\n\rOfferSnapshot\x12&.cometbft.abci.v1.OfferSnapshotRequest\x1a\'.cometbft.abci.v1.OfferSnapshotResponse\x12l\n\x11LoadSnapshotChunk\x12*.cometbft.abci.v1.LoadSnapshotChunkRequest\x1a+.cometbft.abci.v1.LoadSnapshotChunkResponse\x12o\n\x12\x41pplySnapshotChunk\x12+.cometbft.abci.v1.ApplySnapshotChunkRequest\x1a,.cometbft.abci.v1.ApplySnapshotChunkResponse\x12\x66\n\x0fPrepareProposal\x12(.cometbft.abci.v1.PrepareProposalRequest\x1a).cometbft.abci.v1.PrepareProposalResponse\x12\x66\n\x0fProcessProposal\x12(.cometbft.abci.v1.ProcessProposalRequest\x1a).cometbft.abci.v1.ProcessProposalResponse\x12W\n\nExtendVote\x12#.cometbft.abci.v1.ExtendVoteRequest\x1a$.cometbft.abci.v1.ExtendVoteResponse\x12r\n\x13VerifyVoteExtension\x12,.cometbft.abci.v1.VerifyVoteExtensionRequest\x1a-.cometbft.abci.v1.VerifyVoteExtensionResponse\x12`\n\rFinalizeBlock\x12&.cometbft.abci.v1.FinalizeBlockRequest\x1a\'.cometbft.abci.v1.FinalizeBlockResponseB\xb9\x01\n\x14\x63om.cometbft.abci.v1B\x0cServiceProtoP\x01Z1github.com/cometbft/cometbft/api/cometbft/abci/v1\xa2\x02\x03\x43\x41X\xaa\x02\x10\x43ometbft.Abci.V1\xca\x02\x10\x43ometbft\\Abci\\V1\xe2\x02\x1c\x43ometbft\\Abci\\V1\\GPBMetadata\xea\x02\x12\x43ometbft::Abci::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.cometbft.abci.v1B\014ServiceProtoP\001Z1github.com/cometbft/cometbft/api/cometbft/abci/v1\242\002\003CAX\252\002\020Cometbft.Abci.V1\312\002\020Cometbft\\Abci\\V1\342\002\034Cometbft\\Abci\\V1\\GPBMetadata\352\002\022Cometbft::Abci::V1'
  _globals['_ABCISERVICE']._serialized_start=83
  _globals['_ABCISERVICE']._serialized_end=1559
# @@protoc_insertion_point(module_scope)
